@@ -149,16 +149,14 @@ impl Browser {
     pub fn draw_browser<B: Backend>(&self, f: &mut Frame<B>) {
         let area = f.size();
 
+        let size = area.width / 3;
         let chunks = Layout::default()
             .direction(Direction::Horizontal)
-            .constraints(
-                [
-                    Constraint::Percentage(33),
-                    Constraint::Percentage(33),
-                    Constraint::Percentage(33),
-                ]
-                .as_ref(),
-            )
+            .constraints([
+                Constraint::Length(size),
+                Constraint::Length(size),
+                Constraint::Length(size),
+            ])
             .split(area);
 
         let a: Vec<_> = self
@@ -193,7 +191,7 @@ impl Browser {
             .highlight_style(Style::default())
             .highlight_symbol(">");
 
-        let mut artist_state = ListState::new(self.artists.index);
+        let mut artist_state = ListState::new(self.artists.selection());
 
         let albums = List::new(b)
             .block(
@@ -206,7 +204,7 @@ impl Browser {
             .highlight_style(Style::default())
             .highlight_symbol(">");
 
-        let mut album_state = ListState::new(self.albums.index);
+        let mut album_state = ListState::new(self.albums.selection());
 
         let songs = List::new(c)
             .block(
@@ -219,7 +217,7 @@ impl Browser {
             .highlight_style(Style::default())
             .highlight_symbol(">");
 
-        let mut song_state = ListState::new(self.songs.index);
+        let mut song_state = ListState::new(self.songs.selection());
 
         //TODO: better way of doing this?
         match self.mode {
